@@ -1,4 +1,4 @@
-/* Copyright (C) 2009 Carlo de Falco
+/* Copyright (C) 2009, 2020 Carlo de Falco, Rafael Vazquez
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -45,6 +45,9 @@ DEFUN_DLD(surfderivcpts, args, nargout,"\
   
   octave_value_list retval;
 
+  if (nargout != 1 || (args.length () != 8 && args.length() != 12))
+    print_usage ();
+    
   octave_idx_type n = args(0).idx_type_value ();
   octave_idx_type p = args(1).idx_type_value ();
   RowVector U = args(2).row_vector_value (false, true);
@@ -67,15 +70,12 @@ DEFUN_DLD(surfderivcpts, args, nargout,"\
   else if  (args.length () > 8) 
     print_usage ();
 
-  if (! error_state)
-    {
-      
-      NDArray pkl;
+  NDArray pkl;
 
-      surfderivcpts (n, p, U, m, q, V, P, d, r1, r2, s1, s2,  pkl);
+  surfderivcpts (n, p, U, m, q, V, P, d, r1, r2, s1, s2,  pkl);
+
+  retval(0) = octave_value (pkl);
 
-      retval(0) = octave_value (pkl);
-    }
   return retval;
 }
 
